@@ -16,7 +16,7 @@
 
 
 import pikepdf
-import re
+from . import metadata
 
 from decimal import Decimal
 
@@ -34,16 +34,16 @@ def _mediabox(row, angle, angle0, box):
             perm.insert(1, perm.pop(2))
             crop = [crop_init[perm[side]] for side in range(4)]
         # PyPDF2 FloatObject instances are decimal.Decimal objects
-        crop = [Decimal(x) for x in crop]
-        x1, y1, x2, y2 = box
+        x1, y1, x2, y2 = [float(x) for x in box]
         x1_new = x1 + (x2 - x1) * crop[0]
         x2_new = x2 - (x2 - x1) * crop[1]
         y1_new = y1 + (y2 - y1) * crop[3]
         y2_new = y2 - (y2 - y1) * crop[2]
-        return [x1_new, y1_new, x2_new, y2_new]
+        # TODO: check if Decimal is still needed now that we dropped PyPDF2
+        return [Decimal(v) for v in [x1_new, y1_new, x2_new, y2_new]]
 
 
-def export(input_files, pages, file_out, metadata):
+def export(input_files, pages, file_out, mdata):
     pdf_output = pikepdf.Pdf.new()
     pdf_input = [pikepdf.open(p.copyname) for p in input_files]
     for row in pages:
@@ -55,9 +55,10 @@ def export(input_files, pages, file_out, metadata):
         cropped = _mediabox(row, angle, angle0, current_page.MediaBox)
         if cropped:
             current_page.MediaBox = cropped
-        pdf_output.pages.append(current_page)
-    with pdf_output.open_metadata() as outmeta:
+        pdf_output.pages.append(pdf_output.copy_foreign(current_page))
+    ppae = metadata.PRODUCER not in mdata
+    with pdf_output.open_metadata(set_pikepdf_as_editor=ppae) as outmeta:
         outmeta.load_from_docinfo(pdf_input[0].docinfo)
-        for k, v in metadata.items():
+        for k, v in mdata.items():
             outmeta[k] = v
     pdf_output.save(file_out)
