@@ -63,7 +63,7 @@ else:
         pass
 
 APPNAME = 'PDF Arranger'
-VERSION = '1.4.0'
+VERSION = '1.4.1'
 WEBSITE = 'https://github.com/jeromerobert/pdfarranger'
 LICENSE = 'GNU General Public License (GPL) Version 3.'
 
@@ -277,6 +277,8 @@ class PdfArranger(Gtk.Application):
         for f in files:
             a.addpages(f.get_path())
         a.commit()
+        if len(files) == 1:
+            self.set_unsaved(False)
 
     def __create_actions(self):
         # Both Gtk.ApplicationWindow and Gtk.Application are Gio.ActionMap. Some action are window
@@ -676,11 +678,12 @@ class PdfArranger(Gtk.Application):
         if only_selected:
             selection = self.iconview.get_selected_items()
             to_export = [row for row in self.model if row.path in selection]
+        else:
+            self.export_directory = path
+            self.export_file = file_out
+            self.set_unsaved(False)
         m = metadata.merge(self.metadata, self.pdfqueue)
         exporter.export(self.pdfqueue, to_export, file_out, m)
-        self.export_directory = path
-        self.export_file = file_out
-        self.set_unsaved(False)
 
     def choose_export_selection_pdf_name(self, _action, _target, _unknown):
         self.choose_export_pdf_name(True)
@@ -799,6 +802,7 @@ class PdfArranger(Gtk.Application):
                 if target == 'MODEL_ROW_INTERN':
                     move = context.get_actions() & Gdk.DragAction.MOVE
                     self.undomanager.commit("Move" if move else "Copy")
+                    self.set_unsaved(True)
                     data.sort(key=int, reverse=not before)
                     ref_from_list = [Gtk.TreeRowReference.new(model, Gtk.TreePath(p))
                                      for p in data]
@@ -836,6 +840,7 @@ class PdfArranger(Gtk.Application):
             # pdfarranger instance
             return
         self.undomanager.commit("Move")
+        self.set_unsaved(True)
         model = self.iconview.get_model()
         ref_del_list = [Gtk.TreeRowReference.new(model, path) for path in selection]
         for ref_del in ref_del_list:
@@ -1060,7 +1065,8 @@ class PdfArranger(Gtk.Application):
             model.set_value(iterator, 8, 1 - newcrop)
 
     def edit_metadata(self, _action, _parameter, _unknown):
-        metadata.edit(self.metadata, self.pdfqueue, self.window)
+        if metadata.edit(self.metadata, self.pdfqueue, self.window):
+            self.set_unsaved(True)
 
     def crop_page_dialog(self, _action, _parameter, _unknown):
         """Opens a dialog box to define margins for page cropping"""
@@ -1311,6 +1317,7 @@ class PageAdder(object):
         if len(self.pages) == 0:
             return False
         self.app.undomanager.commit("Add")
+        self.app.set_unsaved(True)
         for p in self.pages:
             it = self.app.model.append(p)
             if self.treerowref:
